ispoweroftwo

package
v0.0.0-...-846829c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 5, 2024 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsPowerOfTwo

func IsPowerOfTwo(inputNumber uint) bool

IsPowerOfTwo is function that will use bitwise operations to determine if the given positive number is a power of 2.

Types

This section is empty.

Jump to