package
Version:
v0.0.0-...-846829c
Opens a new window with list of versions in this module.
Published: Aug 5, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func IsPowerOfTwo(inputNumber uint) bool
IsPowerOfTwo is function that will use bitwise operations
to determine if the given positive number is a power of 2.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.